==> jboss-3.2.7-src.tar.bz2: jboss-3.2.7-src/naming/src/main/org/jnp/interfaces/NamingEnumerationImpl.java <==
/*
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 *
 * Copyright 1999 by dreamBean Software,
 * All rights reserved.
 */
package org.jnp.interfaces;

import java.util.Collection;
import java.util.Iterator;

import javax.naming.NamingEnumeration;

/**
 *   <description> 
 *      
 *   @see <related>
 *   @author $Author: oberg $
 *   @version $Revision: 1.2 $
 */
public class NamingEnumerationImpl
   implements NamingEnumeration
{
   // Constants -----------------------------------------------------
    
   // Attributes ----------------------------------------------------
   Iterator enum;
    
   // Static --------------------------------------------------------
   
   // Constructors --------------------------------------------------
   NamingEnumerationImpl(Collection list)
   {
      enum = list.iterator();
   }
   
   // Public --------------------------------------------------------

   // Enumeration implementation ------------------------------------
   public boolean hasMoreElements()
   {
      return enum.hasNext();
   }
   
   public Object nextElement()
   {
      return enum.next();
   }

   // NamingEnumeration implementation ------------------------------
   public boolean hasMore()
   {
      return enum.hasNext();
   }
   
   public Object next()
   {
      return enum.next();
   }
   
   public void close()
   {
      enum = null;
   }

   // Y overrides ---------------------------------------------------

   // Package protected ---------------------------------------------
    
   // Protected -----------------------------------------------------
    
   // Private -------------------------------------------------------

   // Inner classes -------------------------------------------------
}

==> jboss-4.0.1-src.tar.bz2: jboss-4.0.1-src/naming/src/main/org/jnp/interfaces/NamingEnumerationImpl.java <==
/*
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 *
 * Copyright 1999 by dreamBean Software,
 * All rights reserved.
 */
package org.jnp.interfaces;

import java.util.Collection;
import java.util.Iterator;

import javax.naming.NamingEnumeration;

/**
 *  A NamingEnumeration for the Context list/listBindings methods.
 * 
 * @author oberg
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.2.32.1 $
 */
public class NamingEnumerationImpl
   implements NamingEnumeration
{
   // Constants -----------------------------------------------------
 
   // Attributes ----------------------------------------------------
   Iterator iter;
    
   // Static --------------------------------------------------------
   
   // Constructors --------------------------------------------------
   NamingEnumerationImpl(Collection list)
   {
      iter = list.iterator();
   }
   
   // Public --------------------------------------------------------

   // Enumeration implementation ------------------------------------
   public boolean hasMoreElements()
   {
      return iter.hasNext();
   }
   
   public Object nextElement()
   {
      return iter.next();
   }

   // NamingEnumeration implementation ------------------------------
   public boolean hasMore()
   {
      return iter.hasNext();
   }
   
   public Object next()
   {
      return iter.next();
   }
   
   public void close()
   {
      iter = null;
   }

   // Y overrides ---------------------------------------------------

   // Package protected ---------------------------------------------
    
   // Protected -----------------------------------------------------
    
   // Private -------------------------------------------------------

   // Inner classes -------------------------------------------------
}
